@@ -33,7 +33,7 @@
 
 #ifndef lint
 /*static char sccsid[] = "from: @(#)common.c	5.7 (Berkeley) 3/2/91";*/
-static char rcsid[] = "$Id: common.c,v 1.7 1999/10/17 20:07:12 notting Exp $";
+static char rcsid[] = "$Id: common.c,v 1.3 1993/12/08 00:47:01 jtc Exp $";
 #endif /* not lint */
 
 /*
@@ -74,10 +74,8 @@ short	PL;		/* page length */
 short	PX;		/* page width in pixels */
 short	PY;		/* page length in pixels */
 short	BR;		/* baud rate if lp is a tty */
-ulong	FC;		/* flags to clear if lp is a tty */
-ulong	FS;		/* flags to set if lp is a tty */
-ulong	XC;		/* flags to clear for local mode */
-ulong	XS;		/* flags to set for local mode */
+int	FC;		/* flags to clear if lp is a tty */
+int	FS;		/* flags to set if lp is a tty */
 short	RS;		/* restricted to those with local accounts */
 
 char	line[BUFSIZ];
@@ -85,7 +83,7 @@ char	pbuf[BUFSIZ/2];	/* buffer for printcap strings */
 char	*bp = pbuf;	/* pointer into pbuf for pgetent() */
 char	*name;		/* program name */
 char	*printer;	/* printer name */
-char	host[MAXHOSTNAMELEN];	/* host machine name */
+char	host[32];	/* host machine name */
 char	*from = host;	/* client's machine name */
 int	sendtorem;	/* are we sending to a remote? */
 
@@ -114,9 +112,6 @@ getport(rhost)
 	if (sp == NULL)
 		fatal("printer/tcp: unknown service");
 	bzero((char *)&sin, sizeof(sin));
-	if (hp->h_length > sizeof(sin.sin_addr)) {
-		hp->h_length = sizeof(sin.sin_addr);
-	}
 	bcopy(hp->h_addr, (caddr_t)&sin.sin_addr, hp->h_length);
 	sin.sin_family = hp->h_addrtype;
 	sin.sin_port = sp->s_port;
@@ -158,14 +153,14 @@ getline(cfp)
 	register char *lp = line;
 	register c;
 
-	while ((c = getc(cfp)) != '\n' && linel+1 < sizeof(line)) {
+	while ((c = getc(cfp)) != '\n') {
 		if (c == EOF)
 			return(0);
 		if (c == '\t') {
 			do {
 				*lp++ = ' ';
 				linel++;
-			} while ((linel & 07) != 0 && linel+1 < sizeof(line));
+			} while ((linel & 07) != 0);
 			continue;
 		}
 		*lp++ = c;
@@ -193,7 +188,7 @@ getq(namelist)
 
 	if ((dirp = opendir(SD)) == NULL)
 		return(-1);
-	if (fstat(dirfd(dirp), &stbuf) < 0)
+	if (fstat(dirp->dd_fd, &stbuf) < 0)
 		goto errdone;
 
 	/*
@@ -271,16 +266,16 @@ checkremote()
 		name[sizeof(name)-1] = '\0';
 		hp = gethostbyname(name);
 		if (hp == (struct hostent *) NULL) {
-		    (void) snprintf(errbuf, sizeof(errbuf),
+		    (void) sprintf(errbuf,
 			"unable to get official name for local machine %s",
 			name);
 		    return errbuf;
-		} else (void) strncpy(name, hp->h_name, MAXHOSTNAMELEN);
+		} else (void) strcpy(name, hp->h_name);
 
 		/* get the official name of RM */
 		hp = gethostbyname(RM);
 		if (hp == (struct hostent *) NULL) {
-		    (void) snprintf(errbuf, sizeof(errbuf),
+		    (void) sprintf(errbuf,
 			"unable to get official name for remote machine %s",
 			RM);
 		    return errbuf;
@@ -296,52 +291,9 @@ checkremote()
 	return (char *)0;
 }
 
-/*
- * Figure out whether the local machine is the same
- * as the remote machine (fromhost).
- */
-int
-checkfromremote(fromhost)
-       char *fromhost;
-{
-       char name[MAXHOSTNAMELEN];
-       register struct hostent *hp;
-       static char errbuf[128];
-
-       sendtorem = 0;  /* assume printer is local */
-       /* get the official name of the local host */
-       gethostname(name, sizeof(name));
-       name[sizeof(name)-1] = '\0';
-       hp = gethostbyname(name);
-       if (hp == (struct hostent *) NULL) {
-           (void) snprintf(errbuf, 128,
-               "unable to get official name for local machine %s",
-               name);
-           return 1;
-       } else (void) strncpy(name, hp->h_name, MAXHOSTNAMELEN);
-
-       /* get the official name of fromhost */
-       hp = gethostbyname(fromhost);
-       if (hp == (struct hostent *) NULL) {
-           (void) snprintf(errbuf, 128,
-               "unable to get official name for remote machine %s",
-               fromhost);
-           return 1;
-       }
-
-       /*
-        * if the two hosts are not the same,
-        * then the printer must be remote.
-        */
-       return strcmp(name, hp->h_name) != 0;
-}
-
-
-
 /*VARARGS1*/
 fatal(msg, a1, a2, a3)
 	char *msg;
-	void *a1, *a2, *a3;
 {
 	if (from != host)
 		printf("%s: ", host);
